@@ -2,7 +2,7 @@
 
 # MIT License
 #
-# Copyright (c) 2017 Maxim Biro <nurupo.contributions@gmail.com>
+# Copyright (c) 2017-2018 Maxim Biro <nurupo.contributions@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -38,9 +38,9 @@ readonly QTOX_SRC_DIR="/qtox"
 
 
 # Make sure we run in an expected environment
-if [ ! -f /etc/os-release ] || ! cat /etc/os-release | grep -qi 'stretch'
+if [ ! -f /etc/os-release ] || ! cat /etc/os-release | grep -qi 'buster'
 then
-  echo "Error: This script should be run on Debian Stretch."
+  echo "Error: This script should be run on Debian Buster."
   exit 1
 fi
 
@@ -97,10 +97,32 @@ fi
 
 readonly BUILD_DIR="/build"
 readonly DEP_DIR="$WORKSPACE_DIR/$ARCH/dep-cache"
+readonly APT_CACHE_DIR="$WORKSPACE_DIR/$ARCH/apt_cache"
 
+# Create the expected directory structure
+
+# Just make sure those exist
+mkdir -p "$WORKSPACE_DIR"
+mkdir -p "$DEP_DIR"
+mkdir -p "$APT_CACHE_DIR"
+
+# Build dir should be empty
+rm -rf "$BUILD_DIR"
+mkdir -p "$BUILD_DIR"
+cd "$BUILD_DIR"
 
 set -x
 
+echo "Restoring package cache"
+# ensure at least one file exists
+touch "$APT_CACHE_DIR"/dummy
+# restore apt cache
+cp -r "$APT_CACHE_DIR"/* /var/cache/
+
+# remove docker specific config file, this file prevents usage of the package cache
+rm -f /etc/apt/apt.conf.d/docker-clean
+
+readonly WGET_OPTIONS="--timeout=10"
 
 # Get packages
 
@@ -114,6 +136,7 @@ apt-get install -y --no-install-recommends \
                    cmake \
                    git \
                    libtool \
+                   nsis \
                    pkg-config \
                    tclsh \
                    unzip \
@@ -145,18 +168,6 @@ fi
 set -u
 
 
-# Create the expected directory structure
-
-# Just make sure those exist
-mkdir -p "$WORKSPACE_DIR"
-mkdir -p "$DEP_DIR"
-
-# Build dir should be empty
-rm -rf "$BUILD_DIR"
-mkdir -p "$BUILD_DIR"
-cd "$BUILD_DIR"
-
-
 # Use all cores for building
 
 MAKEFLAGS=j$(nproc)
@@ -206,26 +217,34 @@ strip_all()
   set -e
 }
 
+# Store apt cache
+store_apt_cache()
+{
+  # prevent old packages from polluting the cache
+  apt-get autoclean
+  cp -r /var/cache/apt/ "$APT_CACHE_DIR"
+}
+
 
 # OpenSSL
 
 OPENSSL_PREFIX_DIR="$DEP_DIR/libopenssl"
-OPENSSL_VERSION=1.0.2o
+OPENSSL_VERSION=1.1.1f
 # hash from https://www.openssl.org/source/
-OPENSSL_HASH="ec3f5c9714ba0fd45cb4e087301eb1336c317e0d20b575a125050470e8089e4d"
+OPENSSL_HASH="186c6bfe6ecfba7a5b48c47f8a1673d0f3b0e5ba2e25602dd23b629975da3f35"
 OPENSSL_FILENAME="openssl-$OPENSSL_VERSION.tar.gz"
 if [ ! -f "$OPENSSL_PREFIX_DIR/done" ]
 then
   rm -rf "$OPENSSL_PREFIX_DIR"
   mkdir -p "$OPENSSL_PREFIX_DIR"
 
-  wget "https://www.openssl.org/source/$OPENSSL_FILENAME"
+  wget $WGET_OPTIONS "https://www.openssl.org/source/$OPENSSL_FILENAME"
   check_sha256 "$OPENSSL_HASH" "$OPENSSL_FILENAME"
   bsdtar --no-same-owner --no-same-permissions -xf "$OPENSSL_FILENAME"
   rm $OPENSSL_FILENAME
   cd openssl*
 
-  CONFIGURE_OPTIONS="--prefix=$OPENSSL_PREFIX_DIR shared"
+  CONFIGURE_OPTIONS="--prefix=$OPENSSL_PREFIX_DIR --openssldir=${OPENSSL_PREFIX_DIR}/ssl shared"
   if [[ "$ARCH" == "x86_64" ]]
   then
     CONFIGURE_OPTIONS="$CONFIGURE_OPTIONS mingw64 --cross-compile-prefix=x86_64-w64-mingw32-"
@@ -252,18 +271,18 @@ fi
 
 QT_PREFIX_DIR="$DEP_DIR/libqt5"
 QT_MAJOR=5
-QT_MINOR=9
-QT_PATCH=6
+QT_MINOR=12
+QT_PATCH=8
 QT_VERSION=$QT_MAJOR.$QT_MINOR.$QT_PATCH
-# hash from https://download.qt.io/archive/qt/5.9/5.9.6/single/qt-everywhere-opensource-src-5.9.6.tar.xz.mirrorlist
-QT_HASH="dacc995ae3a7cdad80eb9fdf6470299a8fac41f468a9bb941670ece523b62af4"
-QT_FILENAME="qt-everywhere-opensource-src-$QT_VERSION.tar.xz"
+# hash from https://download.qt.io/archive/qt/5.12/5.12.8/single/qt-everywhere-src-5.12.8.tar.xz.mirrorlist
+QT_HASH="9142300dfbd641ebdea853546511a352e4bd547c4c7f25d61a40cd997af1f0cf"
+QT_FILENAME="qt-everywhere-src-$QT_VERSION.tar.xz"
 if [ ! -f "$QT_PREFIX_DIR/done" ]
 then
   rm -rf "$QT_PREFIX_DIR"
   mkdir -p "$QT_PREFIX_DIR"
 
-  wget "https://download.qt.io/official_releases/qt/$QT_MAJOR.$QT_MINOR/$QT_VERSION/single/$QT_FILENAME"
+  wget $WGET_OPTIONS "https://download.qt.io/official_releases/qt/$QT_MAJOR.$QT_MINOR/$QT_VERSION/single/$QT_FILENAME"
   check_sha256 "$QT_HASH" "$QT_FILENAME"
   bsdtar --no-same-owner --no-same-permissions -xf $QT_FILENAME
   rm $QT_FILENAME
@@ -303,7 +322,6 @@ then
     -skip datavis3d \
     -skip declarative \
     -skip doc \
-    -skip enginio \
     -skip gamepad \
     -skip graphicaleffects \
     -skip imageformats \
@@ -326,13 +344,13 @@ then
     -skip wayland \
     -skip webchannel \
     -skip webengine \
+    -skip webglplugin \
     -skip websockets \
     -skip webview \
     -skip x11extras \
     -skip xmlpatterns \
     -no-dbus \
     -no-icu \
-    -no-qml-debug \
     -no-compile-examples \
     -qt-libjpeg \
     -qt-libpng \
@@ -360,6 +378,7 @@ if [[ "$TRAVIS_CI_STAGE" == "stage1" ]]
 then
   # Strip to reduce cache size
   strip_all
+  store_apt_cache
   # Chmod since everything is root:root
   chmod 777 -R "$WORKSPACE_DIR"
   exit 0
@@ -370,23 +389,24 @@ set -u
 # SQLCipher
 
 SQLCIPHER_PREFIX_DIR="$DEP_DIR/libsqlcipher"
-SQLCIPHER_VERSION=v3.4.2
-SQLCIPHER_HASH="69897a5167f34e8a84c7069f1b283aba88cdfa8ec183165c4a5da2c816cfaadb"
+SQLCIPHER_VERSION=v4.3.0
+SQLCIPHER_HASH="fccb37e440ada898902b294d02cde7af9e8706b185d77ed9f6f4d5b18b4c305f"
 SQLCIPHER_FILENAME="$SQLCIPHER_VERSION.tar.gz"
 if [ ! -f "$SQLCIPHER_PREFIX_DIR/done" ]
 then
   rm -rf "$SQLCIPHER_PREFIX_DIR"
   mkdir -p "$SQLCIPHER_PREFIX_DIR"
 
-  wget "https://github.com/sqlcipher/sqlcipher/archive/$SQLCIPHER_FILENAME"
+  wget $WGET_OPTIONS "https://github.com/sqlcipher/sqlcipher/archive/$SQLCIPHER_FILENAME"
   check_sha256 "$SQLCIPHER_HASH" "$SQLCIPHER_FILENAME"
   bsdtar --no-same-owner --no-same-permissions -xf "$SQLCIPHER_FILENAME"
   rm $SQLCIPHER_FILENAME
   cd sqlcipher*
 
-  sed -i s/'LIBS="-lcrypto  $LIBS"'/'LIBS="-lcrypto -lgdi32  $LIBS"'/g configure
-  sed -i s/'LIBS="-lcrypto $LIBS"'/'LIBS="-lcrypto -lgdi32  $LIBS"'/g configure
+  sed -i s/'LIBS="-lcrypto  $LIBS"'/'LIBS="-lcrypto -lgdi32 -lws2_32  $LIBS"'/g configure
+  sed -i s/'LIBS="-lcrypto $LIBS"'/'LIBS="-lcrypto -lgdi32 -lws2_32 $LIBS"'/g configure
   sed -i s/'if test "$TARGET_EXEEXT" = ".exe"'/'if test ".exe" = ".exe"'/g configure
+  sed -i 's|exec $PWD/mksourceid manifest|exec $PWD/mksourceid.exe manifest|g' tool/mksqlite3h.tcl
 
 # Do not remove trailing whitespace and dont replace tabs with spaces in the patch below,
 #  otherwise the patch will fail to apply
@@ -430,15 +450,15 @@ fi
 # FFmpeg
 
 FFMPEG_PREFIX_DIR="$DEP_DIR/libffmpeg"
-FFMPEG_VERSION=4.0.1
-FFMPEG_HASH="605f5c01c60db35d3b617a79cabb2c7032412be243554602eeed1b628125c0ee"
+FFMPEG_VERSION=4.2.2
+FFMPEG_HASH="cb754255ab0ee2ea5f66f8850e1bd6ad5cac1cd855d0a2f4990fb8c668b0d29c"
 FFMPEG_FILENAME="ffmpeg-$FFMPEG_VERSION.tar.xz"
 if [ ! -f "$FFMPEG_PREFIX_DIR/done" ]
 then
   rm -rf "$FFMPEG_PREFIX_DIR"
   mkdir -p "$FFMPEG_PREFIX_DIR"
 
-  wget "https://www.ffmpeg.org/releases/$FFMPEG_FILENAME"
+  wget $WGET_OPTIONS "https://www.ffmpeg.org/releases/$FFMPEG_FILENAME"
   check_sha256 "$FFMPEG_HASH" "$FFMPEG_FILENAME"
   bsdtar --no-same-owner --no-same-permissions -xf $FFMPEG_FILENAME
   rm $FFMPEG_FILENAME
@@ -530,6 +550,26 @@ then
   git checkout $OPENAL_VERSION
   check_sha256_git "$OPENAL_HASH"
 
+# https://github.com/microsoft/vcpkg/blob/3baf583934f3077070e9ed4e7684f743ecced577/ports/openal-soft/cmake-3-11.patch
+> cmake-3-11.patch cat << "EOF"
+diff --git a/CMakeLists.txt b/CMakeLists.txt
+index a871f4c..f9f6b34 100644
+--- a/CMakeLists.txt
++++ b/CMakeLists.txt
+@@ -965,7 +965,8 @@ OPTION(ALSOFT_REQUIRE_DSOUND "Require DirectSound backend" OFF)
+ OPTION(ALSOFT_REQUIRE_MMDEVAPI "Require MMDevApi backend" OFF)
+ IF(HAVE_WINDOWS_H)
+     # Check MMSystem backend
+-    CHECK_INCLUDE_FILES("windows.h;mmsystem.h" HAVE_MMSYSTEM_H -D_WIN32_WINNT=0x0502)
++    set(CMAKE_REQUIRED_DEFINITIONS -D_WIN32_WINNT=0x0502)
++    CHECK_INCLUDE_FILES("windows.h;mmsystem.h" HAVE_MMSYSTEM_H)
+     IF(HAVE_MMSYSTEM_H)
+         CHECK_SHARED_FUNCTION_EXISTS(waveOutOpen "windows.h;mmsystem.h" winmm "" HAVE_LIBWINMM)
+         IF(HAVE_LIBWINMM)
+EOF
+
+  patch -l < cmake-3-11.patch
+
   mkdir -p build
   cd build
 
@@ -571,136 +611,6 @@ else
 fi
 
 
-# Filteraudio
-
-FILTERAUDIO_PREFIX_DIR="$DEP_DIR/libfilteraudio"
-FILTERAUDIO_VERSION=ada2f4fdc04940cdeee47caffe43add4fa017096
-FILTERAUDIO_HASH="cf481e87c860aaf28b50d125195d84556f36d0ebb529d7ebdac39f8cc497256a"
-if [ ! -f "$FILTERAUDIO_PREFIX_DIR/done" ]
-then
-  rm -rf "$FILTERAUDIO_PREFIX_DIR"
-  mkdir -p "$FILTERAUDIO_PREFIX_DIR"
-
-  git clone https://github.com/irungentoo/filter_audio filter_audio
-  cd filter*
-  git checkout $FILTERAUDIO_VERSION
-  check_sha256_git "$FILTERAUDIO_HASH"
-
-  $ARCH-w64-mingw32-gcc -O2 -g0 -c \
-               aec/aec_core.c \
-               aec/aec_core_sse2.c \
-               aec/aec_rdft.c \
-               aec/aec_rdft_sse2.c \
-               aec/aec_resampler.c \
-               aec/echo_cancellation.c \
-               agc/analog_agc.c \
-               agc/digital_agc.c \
-               ns/ns_core.c \
-               ns/nsx_core_c.c \
-               ns/nsx_core.c \
-               ns/noise_suppression_x.c \
-               ns/noise_suppression.c \
-               other/get_scaling_square.c \
-               other/resample_by_2.c \
-               other/spl_sqrt.c \
-               other/delay_estimator.c \
-               other/complex_bit_reverse.c \
-               other/dot_product_with_scale.c \
-               other/cross_correlation.c \
-               other/min_max_operations.c \
-               other/resample_48khz.c \
-               other/high_pass_filter.c \
-               other/energy.c \
-               other/randomization_functions.c \
-               other/speex_resampler.c \
-               other/copy_set_operations.c \
-               other/downsample_fast.c \
-               other/complex_fft.c \
-               other/vector_scaling_operations.c \
-               other/resample_by_2_internal.c \
-               other/delay_estimator_wrapper.c \
-               other/real_fft.c \
-               other/spl_sqrt_floor.c \
-               other/resample_fractional.c \
-               other/ring_buffer.c \
-               other/splitting_filter.c \
-               other/fft4g.c \
-               other/division_operations.c \
-               other/spl_init.c \
-               other/float_util.c \
-               zam/filters.c \
-               vad/vad_sp.c \
-               vad/vad_core.c \
-               vad/webrtc_vad.c \
-               vad/vad_gmm.c \
-               vad/vad_filterbank.c \
-               filter_audio.c \
-               -lpthread \
-               -lm
-
-  ar rcs libfilteraudio.a \
-    aec_core.o \
-    aec_core_sse2.o \
-    aec_rdft.o \
-    aec_rdft_sse2.o \
-    aec_resampler.o \
-    echo_cancellation.o \
-    analog_agc.o \
-    digital_agc.o \
-    ns_core.o \
-    nsx_core_c.o \
-    nsx_core.o \
-    noise_suppression_x.o \
-    noise_suppression.o \
-    get_scaling_square.o \
-    resample_by_2.o \
-    spl_sqrt.o \
-    delay_estimator.o \
-    complex_bit_reverse.o \
-    dot_product_with_scale.o \
-    cross_correlation.o \
-    min_max_operations.o \
-    resample_48khz.o \
-    high_pass_filter.o \
-    energy.o \
-    randomization_functions.o \
-    speex_resampler.o \
-    copy_set_operations.o \
-    downsample_fast.o \
-    complex_fft.o \
-    vector_scaling_operations.o \
-    resample_by_2_internal.o \
-    delay_estimator_wrapper.o \
-    real_fft.o \
-    spl_sqrt_floor.o \
-    resample_fractional.o \
-    ring_buffer.o \
-    splitting_filter.o \
-    fft4g.o \
-    division_operations.o \
-    spl_init.o \
-    float_util.o \
-    filters.o \
-    vad_sp.o \
-    vad_core.o \
-    webrtc_vad.o \
-    vad_gmm.o \
-    vad_filterbank.o \
-    filter_audio.o
-
-  mkdir $FILTERAUDIO_PREFIX_DIR/include
-  mkdir $FILTERAUDIO_PREFIX_DIR/lib
-  cp filter_audio.h $FILTERAUDIO_PREFIX_DIR/include
-  cp libfilteraudio.a $FILTERAUDIO_PREFIX_DIR/lib
-  echo -n $FILTERAUDIO_VERSION > $FILTERAUDIO_PREFIX_DIR/done
-
-  cd ..
-  rm -rf ./filter*
-else
-  echo "Using cached build of Filteraudio `cat $FILTERAUDIO_PREFIX_DIR/done`"
-fi
-
-
 # QREncode
 
 QRENCODE_PREFIX_DIR="$DEP_DIR/libqrencode"
@@ -712,7 +622,7 @@ then
   rm -rf "$QRENCODE_PREFIX_DIR"
   mkdir -p "$QRENCODE_PREFIX_DIR"
 
-  wget https://fukuchi.org/works/qrencode/$QRENCODE_FILENAME
+  wget $WGET_OPTIONS https://fukuchi.org/works/qrencode/$QRENCODE_FILENAME
   check_sha256 "$QRENCODE_HASH" "$QRENCODE_FILENAME"
   bsdtar --no-same-owner --no-same-permissions -xf "$QRENCODE_FILENAME"
   rm $QRENCODE_FILENAME
@@ -747,7 +657,7 @@ then
   rm -rf "$EXIF_PREFIX_DIR"
   mkdir -p "$EXIF_PREFIX_DIR"
 
-  wget https://sourceforge.net/projects/libexif/files/libexif/$EXIF_VERSION/$EXIF_FILENAME
+  wget $WGET_OPTIONS https://sourceforge.net/projects/libexif/files/libexif/$EXIF_VERSION/$EXIF_FILENAME
   check_sha256 "$EXIF_HASH" "$EXIF_FILENAME"
   bsdtar --no-same-owner --no-same-permissions -xf $EXIF_FILENAME
   rm $EXIF_FILENAME
@@ -773,15 +683,16 @@ fi
 # Opus
 
 OPUS_PREFIX_DIR="$DEP_DIR/libopus"
-OPUS_VERSION=1.2.1
-OPUS_HASH="cfafd339ccd9c5ef8d6ab15d7e1a412c054bf4cb4ecbbbcc78c12ef2def70732"
+OPUS_VERSION=1.3.1
+# https://archive.mozilla.org/pub/opus/SHA256SUMS.txt
+OPUS_HASH="65b58e1e25b2a114157014736a3d9dfeaad8d41be1c8179866f144a2fb44ff9d"
 OPUS_FILENAME="opus-$OPUS_VERSION.tar.gz"
 if [ ! -f "$OPUS_PREFIX_DIR/done" ]
 then
   rm -rf "$OPUS_PREFIX_DIR"
   mkdir -p "$OPUS_PREFIX_DIR"
 
-  wget "https://archive.mozilla.org/pub/opus/$OPUS_FILENAME"
+  wget $WGET_OPTIONS "https://archive.mozilla.org/pub/opus/$OPUS_FILENAME"
   check_sha256 "$OPUS_HASH" "$OPUS_FILENAME"
   bsdtar --no-same-owner --no-same-permissions -xf "$OPUS_FILENAME"
   rm $OPUS_FILENAME
@@ -807,15 +718,15 @@ fi
 # Sodium
 
 SODIUM_PREFIX_DIR="$DEP_DIR/libsodium"
-SODIUM_VERSION=1.0.16
-SODIUM_HASH="eeadc7e1e1bcef09680fb4837d448fbdf57224978f865ac1c16745868fbd0533"
+SODIUM_VERSION=1.0.18
+SODIUM_HASH="6f504490b342a4f8a4c4a02fc9b866cbef8622d5df4e5452b46be121e46636c1"
 SODIUM_FILENAME="libsodium-$SODIUM_VERSION.tar.gz"
 if [ ! -f "$SODIUM_PREFIX_DIR/done" ]
 then
   rm -rf "$SODIUM_PREFIX_DIR"
   mkdir -p "$SODIUM_PREFIX_DIR"
 
-  wget "https://download.libsodium.org/libsodium/releases/$SODIUM_FILENAME"
+  wget $WGET_OPTIONS "https://download.libsodium.org/libsodium/releases/$SODIUM_FILENAME"
   check_sha256 "$SODIUM_HASH" "$SODIUM_FILENAME"
   bsdtar --no-same-owner --no-same-permissions -xf "$SODIUM_FILENAME"
   rm "$SODIUM_FILENAME"
@@ -840,15 +751,15 @@ fi
 # VPX
 
 VPX_PREFIX_DIR="$DEP_DIR/libvpx"
-VPX_VERSION=v1.7.0
-VPX_HASH="1fec931eb5c94279ad219a5b6e0202358e94a93a90cfb1603578c326abfc1238"
-VPX_FILENAME="libvpx-$VPX_VERSION.tar.bz2"
+VPX_VERSION=v1.8.2
+VPX_HASH="8735d9fcd1a781ae6917f28f239a8aa358ce4864ba113ea18af4bb2dc8b474ac"
+VPX_FILENAME="libvpx-$VPX_VERSION.tar.gz"
 if [ ! -f "$VPX_PREFIX_DIR/done" ]
 then
   rm -rf "$VPX_PREFIX_DIR"
   mkdir -p "$VPX_PREFIX_DIR"
 
-  wget https://github.com/webmproject/libvpx/archive/$VPX_VERSION.tar.gz -O $VPX_FILENAME
+  wget $WGET_OPTIONS https://github.com/webmproject/libvpx/archive/$VPX_VERSION.tar.gz -O $VPX_FILENAME
   check_sha256 "$VPX_HASH" "$VPX_FILENAME"
   bsdtar --no-same-owner --no-same-permissions -xf "$VPX_FILENAME"
   rm $VPX_FILENAME
@@ -857,11 +768,17 @@ then
   if [[ "$ARCH" == "x86_64" ]]
   then
     VPX_TARGET=x86_64-win64-gcc
+    # There is a bug in gcc that breaks avx512 on 64-bit Windows https://gcc.gnu.org/bugzilla/show_bug.cgi?id=54412
+    # VPX fails to build due to it.
+    # This is a workaround as suggested in https://stackoverflow.com/questions/43152633
+    VPX_CFLAGS="-fno-asynchronous-unwind-tables"
   elif [[ "$ARCH" == "i686" ]]
   then
     VPX_TARGET=x86-win32-gcc
+    VPX_CFLAGS=""
   fi
 
+  CFLAGS="$VPX_CFLAGS" \
   CROSS="$ARCH-w64-mingw32-" ./configure --target="$VPX_TARGET" \
                                          --prefix="$VPX_PREFIX_DIR" \
                                          --disable-shared \
@@ -884,15 +801,15 @@ fi
 # Toxcore
 
 TOXCORE_PREFIX_DIR="$DEP_DIR/libtoxcore"
-TOXCORE_VERSION=0.2.3
-TOXCORE_HASH=22c52f286c46d3f802edb6978bcf2a53f8301363e2b745784613427a33ba3a34
+TOXCORE_VERSION=0.2.11
+TOXCORE_HASH="f111285b036d7746ce8d1321cf0b89ec93b4fad8ae90767a24e50230bbee27e1"
 TOXCORE_FILENAME="c-toxcore-$TOXCORE_VERSION.tar.gz"
 if [ ! -f "$TOXCORE_PREFIX_DIR/done" ]
 then
   rm -rf "$TOXCORE_PREFIX_DIR"
   mkdir -p "$TOXCORE_PREFIX_DIR"
 
-  wget https://github.com/TokTok/c-toxcore/archive/v$TOXCORE_VERSION.tar.gz -O $TOXCORE_FILENAME
+  wget $WGET_OPTIONS https://github.com/TokTok/c-toxcore/archive/v$TOXCORE_VERSION.tar.gz -O $TOXCORE_FILENAME
   check_sha256 "$TOXCORE_HASH" "$TOXCORE_FILENAME"
   bsdtar --no-same-owner --no-same-permissions -xf "$TOXCORE_FILENAME"
   rm "$TOXCORE_FILENAME"
@@ -916,7 +833,6 @@ then
 
   cmake -DCMAKE_INSTALL_PREFIX=$TOXCORE_PREFIX_DIR \
         -DBOOTSTRAP_DAEMON=OFF \
-        -DWARNINGS=OFF \
         -DCMAKE_BUILD_TYPE=Release \
         -DENABLE_STATIC=ON \
         -DENABLE_SHARED=OFF \
@@ -967,78 +883,6 @@ else
 fi
 
 
-# NSIS
-
-NSIS_PREFIX_DIR="$DEP_DIR/nsis"
-NSIS_VERSION="Debian Unstable"
-#NSIS_HASH=
-if [ ! -f "$NSIS_PREFIX_DIR/done" ]
-then
-  rm -rf "$NSIS_PREFIX_DIR"
-  mkdir -p "$NSIS_PREFIX_DIR"
-
-  # We want to use NSIS 3, instead of NSIS 2, because it added Windows 8 and 10
-  # support, as well as unicode support. NSIS 3 is not packaged in Debian Stretch
-  # and building it manually appears to be quite a challenge. Luckily it's
-  # packaged in Debian Unstable, so we can backport it to our Debian version
-  # with little effort, utilizing maintainer's build script.
-
-  # Keep the indentation of the next echo command as it is, as apt seems to
-  # ignore preferences starting with whitespace.
-  echo "
-Package: *
-Pin: Release a=unstable
-Pin-Priority: -1
-  " >> /etc/apt/preferences
-  echo "
-  # Needed for NSIS 3
-  deb http://httpredir.debian.org/debian unstable main
-  deb-src http://httpredir.debian.org/debian unstable main
-  " >> /etc/apt/sources.list
-  apt-get update
-  # Get dependencies required for building NSIS
-  apt-get install -y --no-install-recommends \
-    build-essential \
-    devscripts \
-    docbook-xsl-ns \
-    docbook5-xml \
-    dpkg-dev \
-    fakeroot \
-    html2text \
-    libcppunit-dev \
-    mingw-w64 \
-    scons \
-    xsltproc \
-    zlib1g-dev
-  apt-get -t unstable install -y --no-install-recommends debhelper
-  mkdir nsis-build
-  cd nsis-build
-  apt-get -t unstable source nsis
-
-  cd nsis-*
-  # The build script is not parallel enough, this speeds things up greatly
-  sed -i "s/scons / scons -j `nproc` /" debian/rules
-  DEB_BUILD_OPTIONS="parallel=`nproc` nocheck" debuild -b -uc -us
-  cd ..
-  mv nsis-common_*.deb "$NSIS_PREFIX_DIR"
-  mv nsis-doc_*.deb "$NSIS_PREFIX_DIR"
-  mv nsis_*.deb "$NSIS_PREFIX_DIR"
-  mv nsis-pluginapi_*.deb "$NSIS_PREFIX_DIR"
-
-  cd ..
-  rm -rf ./nsis-build
-
-  echo -n $NSIS_VERSION > $NSIS_PREFIX_DIR/done
-else
-  echo "Using cached build of NSIS `cat $NSIS_PREFIX_DIR/done`"
-fi
-# Install NSIS
-dpkg -i "$NSIS_PREFIX_DIR"/nsis-common_*.deb
-dpkg -i "$NSIS_PREFIX_DIR"/nsis-doc_*.deb
-dpkg -i "$NSIS_PREFIX_DIR"/nsis_*.deb
-dpkg -i "$NSIS_PREFIX_DIR"/nsis-pluginapi_*.deb
-
-
 # NSIS ShellExecAsUser plugin
 
 NSISSHELLEXECASUSER_PREFIX_DIR="$DEP_DIR/nsis_shellexecuteasuser"
@@ -1050,7 +894,7 @@ then
   mkdir -p "$NSISSHELLEXECASUSER_PREFIX_DIR"
 
   # Backup: https://web.archive.org/web/20171008011417/http://nsis.sourceforge.net/mediawiki/images/c/c7/ShellExecAsUser.zip
-  wget http://nsis.sourceforge.net/mediawiki/images/c/c7/ShellExecAsUser.zip
+  wget $WGET_OPTIONS http://nsis.sourceforge.net/mediawiki/images/c/c7/ShellExecAsUser.zip
   check_sha256 "$NSISSHELLEXECASUSER_HASH" "ShellExecAsUser.zip"
   unzip ShellExecAsUser.zip 'ShellExecAsUser.dll'
 
@@ -1071,6 +915,7 @@ if [[ "$TRAVIS_CI_STAGE" == "stage2" ]]
 then
   # Strip to reduce cache size
   strip_all
+  store_apt_cache
   # Chmod since everything is root:root
   chmod 777 -R "$WORKSPACE_DIR"
   exit 0
@@ -1125,15 +970,22 @@ then
 fi
 set -u
 
+# Spell check on windows currently not supported, disable
 if [[ "$BUILD_TYPE" == "release" ]]
 then
   cmake -DCMAKE_TOOLCHAIN_FILE=./toolchain.cmake \
         -DCMAKE_BUILD_TYPE=Release \
+        -DSPELL_CHECK=OFF \
+        -DUPDATE_CHECK=ON \
+        -DSTRICT_OPTIONS=ON \
         ..
 elif [[ "$BUILD_TYPE" == "debug" ]]
 then
   cmake -DCMAKE_TOOLCHAIN_FILE=./toolchain.cmake \
         -DCMAKE_BUILD_TYPE=Debug \
+        -DSPELL_CHECK=OFF \
+        -DUPDATE_CHECK=ON \
+        -DSTRICT_OPTIONS=ON \
         ..
 fi
 
@@ -1152,8 +1004,8 @@ cp -r $QT_PREFIX_DIR/plugins/imageformats \
       $QT_PREFIX_DIR/plugins/iconengines \
       $QTOX_PREFIX_DIR
 cp $OPENAL_PREFIX_DIR/bin/OpenAL32.dll $QTOX_PREFIX_DIR
-cp $OPENSSL_PREFIX_DIR/bin/ssleay32.dll \
-   $OPENSSL_PREFIX_DIR/bin/libeay32.dll \
+cp $OPENSSL_PREFIX_DIR/bin/libssl-*.dll \
+   $OPENSSL_PREFIX_DIR/bin/libcrypto-*.dll \
    $QTOX_PREFIX_DIR
 cp /usr/lib/gcc/$ARCH-w64-mingw32/*-posix/libgcc_s_*.dll $QTOX_PREFIX_DIR
 cp /usr/lib/gcc/$ARCH-w64-mingw32/*-posix/libstdc++-6.dll $QTOX_PREFIX_DIR
@@ -1232,5 +1084,8 @@ fi
 cd ..
 rm -rf ./qtox
 
+# Cache APT packages for future runs
+store_apt_cache
+
 # Chmod since everything is root:root
 chmod 777 -R "$WORKSPACE_DIR"
