@@ -1,5 +1,5 @@
 /*
-    Copyright © 2015-2018 by The qTox Project Contributors
+    Copyright © 2015-2019 by The qTox Project Contributors
 
     This file is part of qTox, a Qt-based graphical interface for Tox.
 
@@ -26,7 +26,7 @@ class ActivateDialog : public QDialog
 {
     Q_OBJECT
 public:
-    ActivateDialog(QWidget* parent = 0, Qt::WindowFlags f = 0);
+    ActivateDialog(QWidget* parent = nullptr, Qt::WindowFlags f = nullptr);
     bool event(QEvent* event) override;
 
 signals:
